"""A sample file generated by copier - this file is safe to delete."""


def Add(a: int, b: int) -> int:
    """Add two numbers."""
    return a + b


def Subtract(a: int, b: int) -> int:
    """Subtract two numbers."""
    return a - b
